แพ็คเกจนี้เป็นแพ็คเกจ python ที่โชว์ข้อมูลเกี่ยวกับเจย์
=======================================================

PyPi: https://pypi.org/project/mynameisjay/

สวัสดีจ้าาาา นี่คือแพ็คเกจที่แสดงข้อมูลเกี่ยวกับเจย์ ท่านสามารถดูลิงค์
Facebook Youtube Page และแสดงภาพศิลปะ ascii

วิธีติดตั้ง
~~~~~~~~~~~

เปิด CMD / Terminal

.. code:: python

   pip install mynameisjay

วิธีใช้งานแพ็คเพจนี้
~~~~~~~~~~~~~~~~~~~~

-  เปิด IDLE ขึ้นมาแล้วพิมพ์…

.. code:: python

   from mynameisjay import Jay

   jay = Jay() # ประกาศชื่อคลาส
   jay.show_name() # โชว์ชื่อ
   jay.show_youtube() # โชว์ link youtube
   jay.show_page() # โชว์ link page
   jay.about() #  เกี่ยวกับเจย์
   jay.show_art() # โชว์ภาพศิลปะ

พัฒนาโดย: เจย์ FB: https://www.facebook.com/

YouTube: https://www.youtube.com/
